@@ -16,6 +16,7 @@ from typing import Callable, List, Optional
 
 from rp2.abstract_transaction import AbstractTransaction
 from rp2.configuration import Configuration
+from rp2.logger import LOGGER
 from rp2.rp2_decimal import ZERO, RP2Decimal
 from rp2.rp2_error import RP2TypeError, RP2ValueError
 
@@ -33,32 +34,43 @@ class IntraTransaction(AbstractTransaction):
         spot_price: Optional[RP2Decimal],
         crypto_sent: RP2Decimal,
         crypto_received: RP2Decimal,
-        unique_id: Optional[int] = None,
+        internal_id: Optional[int] = None,
+        unique_id: Optional[str] = None,
         notes: Optional[str] = None,
     ) -> None:
-        if spot_price is None:
-            # Sometimes, when fee is 0 in IntraTransactions, exchanges don't provide the spot_price: this is OK because
-            # if the fee is 0, spot price isn't needed. In this case spot price is assigned 0.
-            spot_price = ZERO
-        super().__init__(configuration, timestamp, asset, "MOVE", spot_price, unique_id, notes)
+        Configuration.type_check("configuration", configuration)
+        self.__crypto_sent: RP2Decimal = configuration.type_check_positive_decimal("crypto_sent", crypto_sent, non_zero=True)
+        self.__crypto_received: RP2Decimal = configuration.type_check_positive_decimal("crypto_received", crypto_received)
+        self.__crypto_fee: RP2Decimal = self.__crypto_sent - self.__crypto_received
+        if spot_price is None or (isinstance(spot_price, RP2Decimal) and spot_price == ZERO):
+            # Sometimes, when fee is 0 in IntraTransactions, exchanges don't provide the spot_price:
+            # - if the fee is 0, this is OK because spot price isn't needed (in this case spot price is assigned 0).
+            # - if the fee is 0, raise an exception
+            if self.__crypto_fee == ZERO:
+                spot_price = ZERO
+            else:
+                raise RP2ValueError(
+                    f"crypto_fee is non-zero ({self.__crypto_fee}) but spot_price is empty or zero: {timestamp} {asset} {crypto_sent} {unique_id} "
+                )
+        super().__init__(configuration, timestamp, asset, "MOVE", spot_price, internal_id, unique_id, notes)
 
         self.__from_exchange: str = configuration.type_check_exchange("from_exchange", from_exchange)
         self.__from_holder: str = configuration.type_check_holder("from_holder", from_holder)
         self.__to_exchange: str = configuration.type_check_exchange("to_exchange", to_exchange)
         self.__to_holder: str = configuration.type_check_holder("to_holder", to_holder)
-        self.__crypto_sent: RP2Decimal = configuration.type_check_positive_decimal("crypto_sent", crypto_sent, non_zero=True)
-        self.__crypto_received: RP2Decimal = configuration.type_check_positive_decimal("crypto_received", crypto_received)
-        self.__crypto_fee: RP2Decimal
         self.__fiat_fee: RP2Decimal
 
         if self.__from_exchange == self.__to_exchange and self.__from_holder == self.__to_holder:
-            raise RP2ValueError(
-                f"{self.asset} {type(self).__name__} ({self.timestamp}, id {self.unique_id}): from/to exchanges/holders are the same: sending to self"
+            LOGGER.warning(
+                "%s %s (%s, id %s): from/to exchanges/holders are the same: sending to self",
+                self.asset,
+                type(self).__name__,
+                str(self.timestamp),
+                self.internal_id,
             )
         if self.__crypto_sent < self.__crypto_received:
-            raise RP2ValueError(f"{self.asset} {type(self).__name__} ({self.timestamp}, id {self.unique_id}): crypto sent < crypto received")
+            raise RP2ValueError(f"{self.asset} {type(self).__name__} ({self.timestamp}, id {self.internal_id}): crypto sent < crypto received")
 
-        self.__crypto_fee = self.__crypto_sent - self.__crypto_received
         self.__fiat_fee = self.__crypto_fee * self.spot_price
 
     def to_string(self, indent: int = 0, repr_format: bool = True, extra_data: Optional[List[str]] = None) -> str:
@@ -82,6 +94,7 @@ class IntraTransaction(AbstractTransaction):
             f"crypto_received={self.crypto_received:.8f}",
             f"crypto_fee={self.crypto_fee:.8f}",
             f"fiat_fee={self.fiat_fee:.4f}",
+            f"unique_id={self.unique_id}",
             f"is_taxable={stringify(self.is_taxable())}",
             f"fiat_taxable_amount={self.fiat_taxable_amount:.4f}",
         ]
