@@ -15,24 +15,27 @@
 import cProfile
 import os
 import sys
-from argparse import ArgumentParser, Namespace, RawTextHelpFormatter
+from argparse import SUPPRESS, ArgumentParser, Namespace, RawTextHelpFormatter
 from datetime import date
 from importlib import import_module
 from pathlib import Path
 from pkgutil import iter_modules
 from types import ModuleType
-from typing import Dict, List
+from typing import Dict, List, Set
 
 from rp2.abstract_accounting_method import AbstractAccountingMethod
 from rp2.abstract_country import AbstractCountry
 from rp2.abstract_report_generator import AbstractReportGenerator
 from rp2.computed_data import ComputedData
-from rp2.configuration import MAX_DATE, MIN_DATE, VERSION, Configuration
+from rp2.configuration import MAX_DATE, MIN_DATE, Configuration
 from rp2.input_data import InputData
+from rp2.localization import set_generation_language
 from rp2.logger import LOG_FILE, LOGGER
 from rp2.ods_parser import open_ods, parse_ods
 from rp2.tax_engine import compute_tax
 
+_VERSION: str = "1.0.7"
+
 _ACCOUNTING_METHOD_PACKAGE = "rp2.plugin.accounting_method"
 _REPORT_GENERATOR_PACKAGE = "rp2.plugin.report"
 
@@ -51,29 +54,37 @@ def _rp2_main_internal(country: AbstractCountry) -> None:
 
     AbstractCountry.type_check("country", country)
 
-    accounting_methods: List[str] = _find_accounting_methods()
-
-    parser = _setup_argument_parser(accounting_methods)
+    parser = _setup_argument_parser(country)
     args = parser.parse_args()
 
+    set_generation_language(args.generation_language)
+
     _setup_paths(parser=parser, configuration_file=args.configuration_file, input_file=args.input_file, output_dir=args.output_dir)
 
     try:
         LOGGER.info("Country: %s", country.country_iso_code)
+        LOGGER.info("Generation Language: %s", args.generation_language)
 
         accounting_method_module: ModuleType = import_module(f"{_ACCOUNTING_METHOD_PACKAGE}.{args.method}", package=_ACCOUNTING_METHOD_PACKAGE)
         if not hasattr(accounting_method_module, "AccountingMethod"):
-            LOGGER.error("Accounting method plugin %s doesn't have an AccountingMethod class")
+            LOGGER.error("Accounting method plugin %s doesn't have an AccountingMethod class", args.method)
             sys.exit(1)
         accounting_method: AbstractAccountingMethod = accounting_method_module.AccountingMethod()
         LOGGER.info("Accounting Method: %s", args.method)
 
         configuration: Configuration = Configuration(
-            configuration_path=args.configuration_file, country=country, from_date=args.from_date, to_date=args.to_date
+            configuration_path=args.configuration_file,
+            country=country,
+            from_date=args.from_date,
+            to_date=args.to_date,
         )
         LOGGER.info("Configuration file: %s", args.configuration_file)
         LOGGER.debug("Configuration object: %s", configuration)
 
+        if args.plugin:
+            LOGGER.error("Command line option '-l' or '--plugin' has been deprecated: use the 'generators' section in the configuration file instead.")
+            sys.exit(1)
+
         if args.asset:
             assets = [args.asset]
         else:
@@ -96,19 +107,10 @@ def _rp2_main_internal(country: AbstractCountry) -> None:
 
             asset_to_computed_data[asset] = computed_data
 
-        # Run non-country-specific report generators
+        # Run report generators (both country-specific and non-country-specific)
         _find_and_run_report_generators(
-            package_path=_REPORT_GENERATOR_PACKAGE,
-            args=args,
-            country=country,
-            accounting_method=accounting_method,
-            asset_to_computed_data=asset_to_computed_data,
-            from_date=configuration.from_date,
-            to_date=configuration.to_date,
-        )
-        # Run country-specific report generators
-        _find_and_run_report_generators(
-            package_path=f"{_REPORT_GENERATOR_PACKAGE}.{country.country_iso_code}",
+            configuration=configuration,
+            package_paths=[_REPORT_GENERATOR_PACKAGE, f"{_REPORT_GENERATOR_PACKAGE}.{country.country_iso_code}"],
             args=args,
             country=country,
             accounting_method=accounting_method,
@@ -125,7 +127,8 @@ def _rp2_main_internal(country: AbstractCountry) -> None:
 
 
 def _find_and_run_report_generators(
-    package_path: str,
+    configuration: Configuration,
+    package_paths: List[str],
     args: Namespace,
     country: AbstractCountry,
     accounting_method: AbstractAccountingMethod,
@@ -133,62 +136,80 @@ def _find_and_run_report_generators(
     from_date: date,
     to_date: date,
 ) -> None:
-    # Load report generator plugins and call their generate() method
-    package: ModuleType = import_module(package_path)
-    plugin_name: str
-    is_package: bool
-    package_found: bool = False
-    for *_, plugin_name, is_package in iter_modules(package.__path__, package.__name__ + "."):
-        if is_package:
+    generators = configuration.generators.copy()
+    for package_path in package_paths:
+        # Load report generator plugins and call their generate() method
+        try:
+            package: ModuleType = import_module(package_path)
+        except ModuleNotFoundError:
+            # Path not found
             continue
-        if args.plugin and plugin_name != f"{_REPORT_GENERATOR_PACKAGE}.{args.plugin}":
-            continue
-        output_module: ModuleType = import_module(plugin_name, package=_REPORT_GENERATOR_PACKAGE)
-        if hasattr(output_module, "Generator"):
-            generator: AbstractReportGenerator = output_module.Generator()
-            LOGGER.debug("Generator object: '%s'", generator)
-            LOGGER.info("Generating output for plugin '%s'", plugin_name)
-            if not hasattr(generator, "generate"):
-                LOGGER.error("Plugin '%s' has no 'generate' method. Exiting...", plugin_name)
-                sys.exit(1)
-            generator.generate(
-                country=country,
-                accounting_method=repr(accounting_method),
-                asset_to_computed_data=asset_to_computed_data,
-                output_dir_path=args.output_dir,
-                output_file_prefix=args.prefix,
-                from_date=from_date,
-                to_date=to_date,
-            )
-        package_found = True
+        plugin_name: str
+        is_package: bool
+        for *_, plugin_name, is_package in iter_modules(package.__path__, package.__name__ + "."):
+            if is_package:
+                continue
+            if plugin_name not in generators:
+                continue
+            generators.remove(plugin_name)
+            output_module: ModuleType = import_module(plugin_name, package=_REPORT_GENERATOR_PACKAGE)
+            if hasattr(output_module, "Generator"):
+                generator: AbstractReportGenerator = output_module.Generator()
+                LOGGER.debug("Generator object: '%s'", generator)
+                LOGGER.info("Generating output for plugin '%s'", plugin_name)
+                if not hasattr(generator, "generate"):
+                    LOGGER.error("Plugin '%s' has no 'generate' method. Exiting...", plugin_name)
+                    sys.exit(1)
+                generator.generate(
+                    country=country,
+                    accounting_method=repr(accounting_method),
+                    asset_to_computed_data=asset_to_computed_data,
+                    output_dir_path=args.output_dir,
+                    output_file_prefix=args.prefix,
+                    from_date=from_date,
+                    to_date=to_date,
+                    generation_language=args.generation_language,
+                )
 
-    if not package_found:
-        if args.plugin:
-            LOGGER.error("Report Generator plugin '%s' not found. Exiting...", args.plugin)
-        else:
-            LOGGER.error("No report generator plugin found. Exiting...")
+    if generators:
+        LOGGER.error("Report generator plugins %s not found. Exiting...", ", ".join(generators))
         sys.exit(1)
 
 
-def _find_accounting_methods() -> List[str]:
+def _validate_accounting_methods(country: AbstractCountry) -> List[str]:
     # Load accounting method plugins
     package: ModuleType = import_module(_ACCOUNTING_METHOD_PACKAGE)
     plugin_name: str
     is_package: bool
     result: List[str] = []
+    accounting_methods: Set[str] = country.get_accounting_methods()
+
+    if not country.get_default_accounting_method():
+        LOGGER.error("No default accounting method defined in the country plugin. Exiting...")
+        sys.exit(1)
+
+    if not country.get_accounting_methods():
+        LOGGER.error("No accounting methods defined in the country plugin. Exiting...")
+        sys.exit(1)
 
     for *_, plugin_name, is_package in iter_modules(package.__path__, package.__name__ + "."):
         if is_package:
             continue
-        result.append(plugin_name.rsplit(".", 1)[1])
+        normalized_plugin_name = plugin_name.rsplit(".", 1)[1]
+        if normalized_plugin_name in accounting_methods:
+            result.append(normalized_plugin_name)
 
     if not result:
         LOGGER.error("No accounting method plugins found. Exiting...")
+        sys.exit(1)
 
-    return result
+    return sorted(result)
 
 
-def _setup_argument_parser(accounting_methods: List[str]) -> ArgumentParser:
+def _setup_argument_parser(country: AbstractCountry) -> ArgumentParser:
+
+    accounting_methods = _validate_accounting_methods(country)
+
     parser: ArgumentParser = ArgumentParser(
         description=(
             "Generate capital gain/loss report and balances for crypto holdings. Links:\n"
@@ -216,18 +237,27 @@ def _setup_argument_parser(accounting_methods: List[str]) -> ArgumentParser:
         metavar="DATE",
         type=date.fromisoformat,
     )
+    parser.add_argument(
+        "-g",
+        "--generation-language",
+        action="store",
+        default=country.get_default_generation_language(),
+        help="Language to use during generation (in ISO 639-1 format)",
+        metavar="GENERATION_LANGUAGE",
+        type=str,
+    )
     parser.add_argument(
         "-l",
         "--plugin",
         action="store",
-        help="Generate report only using the given PLUGIN",
+        help=SUPPRESS,
         metavar="PLUGIN",
         type=str,
     )
     parser.add_argument(
         "-m",
         "--method",
-        default="fifo",
+        default=country.get_default_accounting_method(),
         choices=accounting_methods,
         help=f"accounting method (default: '%(default)s'). Supported values: {', '.join(accounting_methods)}",
         metavar="METHOD",
@@ -264,7 +294,7 @@ def _setup_argument_parser(accounting_methods: List[str]) -> ArgumentParser:
         "-v",
         "--version",
         action="version",
-        version=f"RP2 {VERSION} (https://pypi.org/project/rp2/)",
+        version=f"RP2 {_VERSION} (https://github.com/eprbell/rp2)",
         help="Print RP2 version",
     )
     parser.add_argument(
